# Installation

You can install Marvin with `pip` (note that Marvin requires Python 3.9+):

```shell
pip install marvin
``` 

To verify your installation, run `marvin --help` in your terminal. 

You can upgrade to the latest released version at any time:

```shell
pip install marvin -U
```

## Installing for Development
See the [contributing docs](../../community/development_guide) for instructions on installing Marvin for development.
